"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var lodash_1 = require("lodash");
var default_1 = require("../environments/default");
var Utils_1 = require("./Utils");
var electron_main_1 = require("../electron.main");
var winston = require('winston');
var format = winston.format;
var combine = format.combine, label = format.label, splat = format.splat, timestamp = format.timestamp, align = format.align, printf = format.printf;
var path = require('path');
var container = new winston.Container();
var verbose = !!electron_main_1.LAUNCH_ARGS.verbose;
var level = verbose ? 'debug' : 'warn';
var FileTransport = /** @class */ (function () {
    function FileTransport() {
    }
    FileTransport.build = function () {
        if (lodash_1.isNil(this.fileTransport)) {
            var fName = lodash_1.get(default_1.environment, 'logFileName', 'electron.log');
            var filePath = path.join(Utils_1.getHomeDir(false, electron_main_1.PROFILE, electron_main_1.LAUNCH_ARGS), fName);
            return new winston.transports.File({
                filename: filePath,
                level: 'debug',
                maxFiles: lodash_1.get(default_1.environment, 'logMaxFile', 3),
                maxsize: lodash_1.get(default_1.environment, 'logMaxFilesMb', 1) * 1000000,
            });
        }
        else {
            return this.fileTransport;
        }
    };
    FileTransport.fileTransport = null;
    return FileTransport;
}());
/**
 * The system logger
 * ```
 * provideLogger('foo').info('bar %s', JSON.stringify({ baz: 'bad' }));
 * -> 2021-01-15T16:59:37.654Z info[foo]: bar {"baz":"bad"}
 *
 * const user = { first: 'Mario', last: 'Rossi' };
 * provideLogger('foo').info('bar %s %s', JSON.stringify({ baz: 'bad' }), JSON.stringify(user, null, 2));
 * -> 2021-01-15T16:59:37.656Z info[foo]: bar {"baz":"bad"} {
 *   "first": "Mario",
 *   "last": "Rossi"
 * }
 * ```
 * @param name The name of the logger
 */
function provideLogger(name) {
    var fileTransport = FileTransport.build();
    var logger1 = container.add(name, {
        format: combine(label({ label: name }), splat(), timestamp(), printf(function (info) { return info.timestamp + " " + info.level + " [" + info.label + "]: " + info.message; })),
        transports: [new winston.transports.Console({ level: level }), fileTransport],
    });
    return logger1;
}
exports.provideLogger = provideLogger;
/**
 * Safely prints js objects to terminal
 * @param value the value
 * @param _ not used
 * @param space the spaces to be printed
 */
function safeJsonStringify(value, _, space) {
    var blacklist = ['otp', 'pin', 'password', 'oldPin', 'newPin', 'puk'];
    var safeReplacer = function (key, value1) {
        if (blacklist.includes(key)) {
            return '***';
        }
        return value1;
    };
    return JSON.stringify(value, safeReplacer, space);
}
exports.safeJsonStringify = safeJsonStringify;
function handleGuiLog(args) {
    var _a;
    var guiLogger = provideLogger("Gui." + args.source);
    var message = lodash_1.map((_a = args.messages) !== null && _a !== void 0 ? _a : [], function (m) { return (lodash_1.isString(m) ? m : safeJsonStringify(m)); }).join(', ');
    switch (args.level) {
        case 'Error':
            guiLogger.error(message);
            break;
        case 'Warning':
            guiLogger.warn(message);
            break;
        default:
            guiLogger.info(message);
            break;
    }
}
exports.handleGuiLog = handleGuiLog;
//# sourceMappingURL=logger.js.map